@@ -6,26 +6,24 @@ use std::mem;
 #[derive(Clone)]
 pub struct BufferDeviceAddress {
     handle: vk::Device,
-    fns: vk::ExtBufferDeviceAddressFn,
+    fp: vk::ExtBufferDeviceAddressFn,
 }
 
 impl BufferDeviceAddress {
     pub fn new(instance: &Instance, device: &Device) -> Self {
-        let fns = vk::ExtBufferDeviceAddressFn::load(|name| unsafe {
-            mem::transmute(instance.get_device_proc_addr(device.handle(), name.as_ptr()))
+        let handle = device.handle();
+        let fp = vk::ExtBufferDeviceAddressFn::load(|name| unsafe {
+            mem::transmute(instance.get_device_proc_addr(handle, name.as_ptr()))
         });
-        Self {
-            handle: device.handle(),
-            fns,
-        }
+        Self { handle, fp }
     }
 
-    #[doc = "<https://www.khronos.org/registry/vulkan/specs/1.2-extensions/man/html/vkGetBufferDeviceAddressEXT.html>"]
+    /// <https://www.khronos.org/registry/vulkan/specs/1.3-extensions/man/html/vkGetBufferDeviceAddressEXT.html>
     pub unsafe fn get_buffer_device_address(
         &self,
         info: &vk::BufferDeviceAddressInfoEXT,
     ) -> vk::DeviceAddress {
-        self.fns.get_buffer_device_address_ext(self.handle, info)
+        self.fp.get_buffer_device_address_ext(self.handle, info)
     }
 
     pub fn name() -> &'static CStr {
@@ -33,7 +31,7 @@ impl BufferDeviceAddress {
     }
 
     pub fn fp(&self) -> &vk::ExtBufferDeviceAddressFn {
-        &self.fns
+        &self.fp
     }
 
     pub fn device(&self) -> vk::Device {
