@@ -1,39 +1,33 @@
 use crate::prelude::*;
 use crate::vk;
 use crate::RawPtr;
-use crate::{EntryCustom, Instance};
+use crate::{Entry, Instance};
 use std::ffi::CStr;
 use std::mem;
 
 #[derive(Clone)]
 pub struct MetalSurface {
     handle: vk::Instance,
-    metal_surface_fn: vk::ExtMetalSurfaceFn,
+    fp: vk::ExtMetalSurfaceFn,
 }
 
 impl MetalSurface {
-    pub fn new<L>(entry: &EntryCustom<L>, instance: &Instance) -> Self {
-        let surface_fn = vk::ExtMetalSurfaceFn::load(|name| unsafe {
-            mem::transmute(entry.get_instance_proc_addr(instance.handle(), name.as_ptr()))
+    pub fn new(entry: &Entry, instance: &Instance) -> Self {
+        let handle = instance.handle();
+        let fp = vk::ExtMetalSurfaceFn::load(|name| unsafe {
+            mem::transmute(entry.get_instance_proc_addr(handle, name.as_ptr()))
         });
-        Self {
-            handle: instance.handle(),
-            metal_surface_fn: surface_fn,
-        }
+        Self { handle, fp }
     }
 
-    pub fn name() -> &'static CStr {
-        vk::ExtMetalSurfaceFn::name()
-    }
-
-    #[doc = "<https://www.khronos.org/registry/vulkan/specs/1.2-extensions/man/html/vkCreateMetalSurfaceEXT.html>"]
+    /// <https://www.khronos.org/registry/vulkan/specs/1.3-extensions/man/html/vkCreateMetalSurfaceEXT.html>
     pub unsafe fn create_metal_surface(
         &self,
         create_info: &vk::MetalSurfaceCreateInfoEXT,
         allocation_callbacks: Option<&vk::AllocationCallbacks>,
     ) -> VkResult<vk::SurfaceKHR> {
         let mut surface = mem::zeroed();
-        self.metal_surface_fn
+        self.fp
             .create_metal_surface_ext(
                 self.handle,
                 create_info,
@@ -43,8 +37,12 @@ impl MetalSurface {
             .result_with_success(surface)
     }
 
+    pub fn name() -> &'static CStr {
+        vk::ExtMetalSurfaceFn::name()
+    }
+
     pub fn fp(&self) -> &vk::ExtMetalSurfaceFn {
-        &self.metal_surface_fn
+        &self.fp
     }
 
     pub fn instance(&self) -> vk::Instance {
