@@ -6,9 +6,11 @@ pub use self::debug_marker::DebugMarker;
 pub use self::debug_report::DebugReport;
 pub use self::debug_utils::DebugUtils;
 pub use self::extended_dynamic_state::ExtendedDynamicState;
+pub use self::extended_dynamic_state2::ExtendedDynamicState2;
 pub use self::full_screen_exclusive::FullScreenExclusive;
 pub use self::metal_surface::MetalSurface;
 pub use self::physical_device_drm::PhysicalDeviceDrm;
+pub use self::private_data::PrivateData;
 pub use self::tooling_info::ToolingInfo;
 
 mod buffer_device_address;
@@ -19,7 +21,9 @@ mod debug_marker;
 mod debug_report;
 mod debug_utils;
 mod extended_dynamic_state;
+mod extended_dynamic_state2;
 mod full_screen_exclusive;
 mod metal_surface;
 mod physical_device_drm;
+mod private_data;
 mod tooling_info;
