@@ -6,36 +6,34 @@ use std::mem;
 #[derive(Clone)]
 pub struct Maintenance3 {
     handle: vk::Device,
-    fns: vk::KhrMaintenance3Fn,
+    fp: vk::KhrMaintenance3Fn,
 }
 
 impl Maintenance3 {
     pub fn new(instance: &Instance, device: &Device) -> Self {
-        let fns = vk::KhrMaintenance3Fn::load(|name| unsafe {
-            mem::transmute(instance.get_device_proc_addr(device.handle(), name.as_ptr()))
+        let handle = device.handle();
+        let fp = vk::KhrMaintenance3Fn::load(|name| unsafe {
+            mem::transmute(instance.get_device_proc_addr(handle, name.as_ptr()))
         });
-        Self {
-            handle: device.handle(),
-            fns,
-        }
+        Self { handle, fp }
+    }
+
+    /// <https://www.khronos.org/registry/vulkan/specs/1.3-extensions/man/html/vkGetDescriptorSetLayoutSupportKHR.html>
+    pub unsafe fn get_descriptor_set_layout_support(
+        &self,
+        create_info: &vk::DescriptorSetLayoutCreateInfo,
+        out: &mut vk::DescriptorSetLayoutSupportKHR,
+    ) {
+        self.fp
+            .get_descriptor_set_layout_support_khr(self.handle, create_info, out);
     }
 
     pub fn name() -> &'static CStr {
         vk::KhrMaintenance3Fn::name()
     }
 
-    #[doc = "<https://www.khronos.org/registry/vulkan/specs/1.2-extensions/man/html/vkGetDescriptorSetLayoutSupportKHR.html>"]
-    pub unsafe fn get_descriptor_set_layout_support(
-        &self,
-        create_info: &vk::DescriptorSetLayoutCreateInfo,
-        out: &mut vk::DescriptorSetLayoutSupportKHR,
-    ) {
-        self.fns
-            .get_descriptor_set_layout_support_khr(self.handle, create_info, out);
-    }
-
     pub fn fp(&self) -> &vk::KhrMaintenance3Fn {
-        &self.fns
+        &self.fp
     }
 
     pub fn device(&self) -> vk::Device {
